/*************************************************************************
 * Description: IB Access Control API
 *
 * Copyright (c) 2016-2017 Oracle, Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * - Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *
 * - Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * 
 * - Neither the name of the copyright holder nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ************************************************************************/

#ifndef __IBACL_H__
#define __IBACL_H__

#include <netinet/in.h>

typedef unsigned long long u64;
typedef unsigned int u32;

#define INSTANCE_ACL_ID_SZ 80
#define UUID_SZ 64

int ib_acl_set_state(const char *ifname, int status);
int ib_acl_get_state(const char *ifname);
int ib_acl_get_instances_count(const char *ifname);
int ib_acl_get_instances(const char *ifname, char *buf, int buflen);
int ib_acl_add_instance(const char *ifname, const char *instname);
int ib_acl_del_instance(const char *ifname, const char *instname);
int ib_acl_get_list_count(const char *ifname, const char *instname);
int ib_acl_get_list(const char *ifname, const char *instname, int count,
		    int from, u64 **subnet_prefixes, u64 **guids, u32 **ips,
		    char **uuids);
int ib_acl_add_to_list(const char *ifname, const char *instname, int count,
		       u64 *subnet_prefixes, u64 *guids, u32 *ips, char *uuids);
int ib_acl_nadd_to_list(const char *ifname, const char *instname, int count,
			u64 *subnet_prefixes, u64 *guids, struct in6_addr *ips,
			char *uuids);
int ib_acl_add_guid_range_to_list(const char *ifname, const char *instname,
				  u64 subnet_prefix, u64 guid, int count,
				  u32 ip, char *uuid);
int ib_acl_nadd_guid_range_to_list(const char *ifname, const char *instname,
				   u64 subnet_prefix, u64 guid, int count,
				   struct in6_addr *ip, char *uuid);
int ib_acl_del_from_list(const char *ifname, const char *instname, int count,
			 u64 *subnet_prefixes, u64 *guids);
int ib_acl_del_guid_range_from_list(const char *ifname, const char *instname,
				    u64 subnet_prefix, u64 guid, int count);

#endif
